Constraint Function Templates (ABCs)
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: constraints.const_func
..    :members: constraints/const_func

.. autoclass:: const_func
   :member-order: bysource
   :members:

   .. automethod:: __init__
   .. automethod:: __call__

Constraint Function Library
~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: constraints.const_lib
..    :members: constraints/const_lib

.. autoclass:: single_sim_bound
   :member-order: bysource
   :members:

   .. automethod:: __init__
   .. automethod:: __call__

.. autoclass:: sos_sim_bound
   :member-order: bysource
   :members:

   .. automethod:: __init__
   .. automethod:: __call__

.. autoclass:: sum_sim_bound
   :member-order: bysource
   :members:

   .. automethod:: __init__
   .. automethod:: __call__
